import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * A LUN is a block storage object within a volume. It provides storage for applications that require block-level access and appears as a virtual disk to the connected host. It is formatted with a file system or used as raw storage, enabling precise control over storage resources and performance for specific workloads. Once activated, you need a preview key to consume this resource. Please reach out to Ng-fsx-cloudformation@netapp.com to get the key. To use this resource, you must first create the Link module.
 *
 * @schema CfnLunProps
 */
export interface CfnLunProps {
    /**
     * The password source for the FSx admin user.
     *
     * @schema CfnLunProps#FsxAdminPasswordSource
     */
    readonly fsxAdminPasswordSource: PasswordSource;
    /**
     * The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.
     *
     * @schema CfnLunProps#FileSystemId
     */
    readonly fileSystemId: string;
    /**
     * The ARN of the AWS Lambda function that will be invoked to manage the resource.
     *
     * @schema CfnLunProps#LinkArn
     */
    readonly linkArn: string;
    /**
     * The fully qualified path name of the LUN composed of a '/vol' prefix, the volume name, and base name of the LUN. Example: /vol/volume1/lun1
     *
     * @schema CfnLunProps#Name
     */
    readonly name: string;
    /**
     * The name of the QoS policy for the LUN.
     *
     * @schema CfnLunProps#QosPolicyName
     */
    readonly qosPolicyName?: string;
    /**
     * Size of the LUN. Required when creating a non-clone LUN and disallowed when creating a clone of an existing LUN. A clone's size is taken from the source LUN.
     *
     * @schema CfnLunProps#Size
     */
    readonly size: number;
    /**
     * The initiator groups mapped to this LUN.
     *
     * @schema CfnLunProps#IGroups
     */
    readonly iGroups?: string[];
    /**
     * The SVM information associated with the LUN.
     *
     * @schema CfnLunProps#SVM
     */
    readonly svm: Svm;
    /**
     * The host operating system of the initiator group. All initiators in the group should be hosts of the same operating system.
     *
     * @schema CfnLunProps#OsType
     */
    readonly osType: CfnLunPropsOsType;
}
/**
 * Converts an object of type 'CfnLunProps' to JSON representation.
 */
export declare function toJson_CfnLunProps(obj: CfnLunProps | undefined): Record<string, any> | undefined;
/**
 * @schema PasswordSource
 */
export interface PasswordSource {
    /**
     * A reference to the source of the password, typically an AWS Secrets Manager secret.
     *
     * @schema PasswordSource#Secret
     */
    readonly secret: SecretSource;
}
/**
 * Converts an object of type 'PasswordSource' to JSON representation.
 */
export declare function toJson_PasswordSource(obj: PasswordSource | undefined): Record<string, any> | undefined;
/**
 * @schema SVM
 */
export interface Svm {
    /**
     * The name of the SVM.
     *
     * @schema SVM#Name
     */
    readonly name?: string;
    /**
     * The UUID of the SVM.
     *
     * @schema SVM#UUID
     */
    readonly uuid?: string;
}
/**
 * Converts an object of type 'Svm' to JSON representation.
 */
export declare function toJson_Svm(obj: Svm | undefined): Record<string, any> | undefined;
/**
 * The host operating system of the initiator group. All initiators in the group should be hosts of the same operating system.
 *
 * @schema CfnLunPropsOsType
 */
export declare enum CfnLunPropsOsType {
    /** aix */
    AIX = "aix",
    /** hpux */
    HPUX = "hpux",
    /** hyper_v */
    HYPER_UNDERSCORE_V = "hyper_v",
    /** linux */
    LINUX = "linux",
    /** netware */
    NETWARE = "netware",
    /** openvms */
    OPENVMS = "openvms",
    /** solaris */
    SOLARIS = "solaris",
    /** solaris_efi */
    SOLARIS_UNDERSCORE_EFI = "solaris_efi",
    /** vmware */
    VMWARE = "vmware",
    /** windows */
    WINDOWS = "windows",
    /** windows_2008 */
    WINDOWS_UNDERSCORE_2008 = "windows_2008",
    /** windows_gpt */
    WINDOWS_UNDERSCORE_GPT = "windows_gpt",
    /** xen */
    XEN = "xen"
}
/**
 * @schema SecretSource
 */
export interface SecretSource {
    /**
     * The ARN of the secret stored in AWS Secrets Manager.
     *
     * @schema SecretSource#SecretArn
     */
    readonly secretArn: string;
    /**
     * Reference for the SecretKey. The actual password is stored in AWS Secret Manager.
     *
     * @schema SecretSource#SecretKey
     */
    readonly secretKey: string;
}
/**
 * Converts an object of type 'SecretSource' to JSON representation.
 */
export declare function toJson_SecretSource(obj: SecretSource | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `NetApp::FSxN::Lun`
 *
 * @cloudformationResource NetApp::FSxN::Lun
 * @stability external
 * @link https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
 */
export declare class CfnLun extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "NetApp::FSxN::Lun";
    /**
     * Resource props.
     */
    readonly props: CfnLunProps;
    /**
     * Attribute `NetApp::FSxN::Lun.UUID`
     * @link https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
     */
    readonly attrUuid: string;
    /**
     * Create a new `NetApp::FSxN::Lun`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnLunProps);
}
